==> tuia-news-center-api-0.0.34-xt9-20180524.012722-1-sources.jar: cn/com/duiba/tuia/news/center/dto/LimitPacketConditionDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.io.Serializable;
import java.util.List;

/**
 * Created by xiaotian on 2018/5/21.
 */
public class LimitPacketConditionDto implements Serializable{


    /**
     * 红包Id
     */
    private Long packetId;

    /**
     * 是否可开启下一个红包
     */
    private boolean canHaveNext;

    /**
     * 是否是自己的红包
     */

    private boolean self;

    /**
     * 红包的用户Id
     */
    private Long userId;

    /**
     * 限时红包的最大金额
     */
    private Long packetAllCount;

    /**
     * 当前收集金额
     */
    private Long presentCount;

    /**
     * 红包剩余时间
     */
    private Long remainTime;

    /**
     * 帮戳人员的记录
     */
    private List<LimitOperateDto> operateDtos;

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getPacketId() {
        return packetId;
    }

    public void setPacketId(Long packetId) {
        this.packetId = packetId;
    }

    public boolean isCanHaveNext() {
        return canHaveNext;
    }

    public void setCanHaveNext(boolean canHaveNext) {
        this.canHaveNext = canHaveNext;
    }

    public boolean isSelf() {
        return self;
    }

    public void setSelf(boolean self) {
        this.self = self;
    }

    public Long getPacketAllCount() {
        return packetAllCount;
    }

    public void setPacketAllCount(Long packetAllCount) {
        this.packetAllCount = packetAllCount;
    }

    public Long getPresentCount() {
        return presentCount;
    }

    public void setPresentCount(Long presentCount) {
        this.presentCount = presentCount;
    }

    public Long getRemainTime() {
        return remainTime;
    }

    public void setRemainTime(Long remainTime) {
        this.remainTime = remainTime;
    }

    public List<LimitOperateDto> getOperateDtos() {
        return operateDtos;
    }

    public void setOperateDtos(List<LimitOperateDto> operateDtos) {
        this.operateDtos = operateDtos;
    }
}

==> tuia-news-center-api-0.0.41-xt1-20180611.020220-1-sources.jar: cn/com/duiba/tuia/news/center/dto/LimitPacketConditionDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.io.Serializable;
import java.util.List;

/**
 * Created by xiaotian on 2018/5/21.
 */
public class LimitPacketConditionDto implements Serializable{


    /**
     * 红包Id
     */
    private Long packetId;

    /**
     * 是否可开启下一个红包
     */
    private boolean canHaveNext;

    /**
     * 当前是第几个红包
     */
    private Integer packetSort = 0;

    /**
     * 是否是自己的红包
     */

    private boolean self;

    /**
     * 红包所属的用户的名称
     */
    private String name;

    /**
     * 用户头像
     */
    private String headImg;

    /**
     * 红包的用户Id
     */
    private Long userId;

    /**
     * 限时红包的最大金额
     */
    private Long packetAllCount;

    /**
     * 当前收集金额
     */
    private Long presentCount;

    /**
     * 红包剩余时间
     */
    private Long remainTime = 0L;

    /**
     * 帮戳人员的记录
     */
    private List<LimitOperateDto> operateDtos;

    public Integer getPacketSort() {
        return packetSort;
    }

    public void setPacketSort(Integer packetSort) {
        this.packetSort = packetSort;
    }

    public String getHeadImg() {
        return headImg;
    }

    public void setHeadImg(String headImg) {
        this.headImg = headImg;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getPacketId() {
        return packetId;
    }

    public void setPacketId(Long packetId) {
        this.packetId = packetId;
    }

    public boolean isCanHaveNext() {
        return canHaveNext;
    }

    public void setCanHaveNext(boolean canHaveNext) {
        this.canHaveNext = canHaveNext;
    }

    public boolean isSelf() {
        return self;
    }

    public void setSelf(boolean self) {
        this.self = self;
    }

    public Long getPacketAllCount() {
        return packetAllCount;
    }

    public void setPacketAllCount(Long packetAllCount) {
        this.packetAllCount = packetAllCount;
    }

    public Long getPresentCount() {
        return presentCount;
    }

    public void setPresentCount(Long presentCount) {
        this.presentCount = presentCount;
    }

    public Long getRemainTime() {
        return remainTime;
    }

    public void setRemainTime(Long remainTime) {
        this.remainTime = remainTime;
    }

    public List<LimitOperateDto> getOperateDtos() {
        return operateDtos;
    }

    public void setOperateDtos(List<LimitOperateDto> operateDtos) {
        this.operateDtos = operateDtos;
    }
}
